Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
lmcat\__init__.py | (no class) | 2 | 0 | 0 | 100%
lmcat\__main__.py | (no class) | 3 | 3 | 0 | 0%
lmcat\file_stats.py | TokenizerWrapper | 7 | 0 | 0 | 100%
lmcat\file_stats.py | FileStats | 6 | 0 | 0 | 100%
lmcat\file_stats.py | TreeEntry | 0 | 0 | 0 | 100%
lmcat\file_stats.py | (no class) | 29 | 7 | 0 | 76%
lmcat\lmcat.py | LMCatConfig | 22 | 19 | 0 | 14%
lmcat\lmcat.py | IgnoreHandler | 10 | 1 | 0 | 90%
lmcat\lmcat.py | (no class) | 156 | 31 | 0 | 80%
lmcat\processing_pipeline.py | ProcessingPipeline | 44 | 8 | 0 | 82%
lmcat\processing_pipeline.py | (no class) | 27 | 4 | 0 | 85%
lmcat\processors.py | (no class) | 82 | 51 | 0 | 38%
tests\_temp\plugins_test\test_plugin.py | (no class) | 8 | 0 | 0 | 100%
tests\test_lmcat.py | (no class) | 193 | 11 | 0 | 94%
tests\test_lmcat_2.py | (no class) | 87 | 23 | 0 | 74%
tests\test_lmcat_3.py | (no class) | 99 | 2 | 0 | 98%
Total |  | 775 | 160 | 0 | 79%

No items found using the specified filter.